@@ -1,6 +1,6 @@
 #define QT_FEATURE_wayland_client 1
 
-#define QT_FEATURE_wayland_server 1
+#define QT_FEATURE_wayland_server -1
 
 #define QT_FEATURE_wayland_egl 1
 
@@ -18,5 +18,5 @@
 
 #define QT_FEATURE_wayland_datadevice 1
 
-#define QT_FEATURE_wayland_decoration_adwaita -1
+#define QT_FEATURE_wayland_decoration_adwaita 1
 
